========================
Octavia Controller Flows
========================

Octavia uses OpenStack TaskFlow to orchestrate the actions the Octavia
controller needs to take while managing load balancers.

This document is meant as a reference for the key flows used in the
Octavia controller.

.. note:: Flow diagrams are temporarly disabled due to a dependency issue.

.. toctree::
    :maxdepth: 1

.. TODO(johnsom) Re-enable flow diagrams when networkx supports individual
..               extras. See https://github.com/networkx/networkx/pull/3080
..    flow_diagrams/AmphoraFlows.rst
..    flow_diagrams/HealthMonitorFlows.rst
..    flow_diagrams/L7PolicyFlows.rst
..    flow_diagrams/L7RuleFlows.rst
..    flow_diagrams/ListenerFlows.rst
..    flow_diagrams/LoadBalancerFlows.rst
..    flow_diagrams/MemberFlows.rst
..    flow_diagrams/PoolFlows.rst
